@@ -1,6 +1,7 @@
 """Pylons environment configuration"""
 import os
 
+from sqlalchemy import engine_from_config
 from pylons import config
 
 import ckan.lib.app_globals as app_globals
@@ -31,3 +32,5 @@ def load_environment(global_conf, app_conf):
 
     # CONFIGURATION OPTIONS HERE (note: all config options will override
     # any Pylons config options)
+    config['pylons.g'].sa_engine = engine_from_config(config, 'sqlalchemy.')
+
